# Basic field

The basic field is a standard free text input field

![Basic fields](../screenshots/fields/waf-basic-field.png)

## Configuration options

There are a number of fields that can be manipulated to serve a basic field

### Label

The 'name' of the field

### Required

Whether or not it is a required field

### Max length

Set a maximum length that the field can accept

### Default value

Set a default value to display in the field when the form initialises

### Help text

Set the help text to sit alongside the field

### Rules and conditions

Set conditional display rules based on other form field values.


